==> hometec_ui-1.0.0.tar.gz: lib/components/dialog/alert_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:hometec_ui/resources/colors/color.dart';
import 'package:hometec_ui/resources/fonts/font.dart';

  Future<void> showAlertDialog(BuildContext context, {String title, String message, String buttonText, Function buttonAction}) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false,
      builder: (BuildContext context) {
        return AlertDialog(
          backgroundColor: ECColor.cards,
          title: Text(title, style: Font.headlineFive.style(color: ECColor.primary),),
          content: Text(message, style: Font.captionRegular.style(color: ECColor.textColor), maxLines: 10,),
          actions: <Widget>[
            FlatButton(
              child: Text('Cancelar', style: Font.bodyRegular.style(color: ECColor.secondary),),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            FlatButton(
              child: Text(buttonText, style: Font.bodyRegular.style(color: ECColor.secondary),),
              onPressed: (){
                Navigator.of(context).pop();
                buttonAction();
              },
            )
          ],
        );
      },
    );
  }

  Future<void> showErrorDialog(BuildContext context, {String title, String message, String buttonText, Function buttonAction}) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          backgroundColor: ECColor.cards,
          title: Text(title, style: Font.headlineFive.style(color: ECColor.primary),),
          content: Text(message, style: Font.captionRegular.style(color: ECColor.textColor), maxLines: 10,),
          actions: <Widget>[
            FlatButton(
              child: Text(buttonText, style: Font.bodyRegular.style(color: ECColor.secondary),),
              onPressed: (){
                buttonAction();
                Navigator.of(context).pop();
              },
            )
          ],
        );
      },
    );
  }

==> hometec_ui-1.1.8.tar.gz: lib/components/dialog/alert_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:hometec_ui/resources/colors/color.dart';
import 'package:hometec_ui/resources/fonts/font.dart';

  Future<void> showAlertDialog(BuildContext context, {String title, String message, String buttonText, Function buttonAction}) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false,
      builder: (BuildContext context) {
        return AlertDialog(
          backgroundColor: ECColor.cards,
          title: Text(title, style: Font.headlineFive.style(color: ECColor.primary),),
          content: Text(message, style: Font.captionRegular.style(color: ECColor.textColor)),
          actions: <Widget>[
            FlatButton(
              child: Text('Cancelar', style: Font.bodyRegular.style(color: ECColor.secondary),),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            FlatButton(
              child: Text(buttonText, style: Font.bodyRegular.style(color: ECColor.secondary),),
              onPressed: (){
                Navigator.of(context).pop();
                buttonAction();
              },
            )
          ],
        );
      },
    );
  }

  Future<void> showErrorAlertDialog(BuildContext context, {String title, String message, String buttonText, Function buttonAction}) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false,
      builder: (BuildContext context) {
        return AlertDialog(
          backgroundColor: ECColor.cards,
          title: Text(title, style: Font.headlineFive.style(color: ECColor.primary),),
          content: Text(message, style: Font.captionRegular.style(color: ECColor.textColor)),
          actions: <Widget>[
            FlatButton(
              child: Text(buttonText, style: Font.bodyRegular.style(color: ECColor.secondary),),
              onPressed: (){
                Navigator.of(context).pop();
                buttonAction();
              },
            )
          ],
        );
      },
    );
  }
